Learn R Programming

SGP (version 0.9-0.0)

growthAchievementPlot_Styles: growthAchievementPlot Styles for SGP

Description

Function that contains styles associated with the use of the growthAchievementPlot to create growth and achievement plots depicting system level results associated with student growth percentile results. The charts show, simultaneously, norm- and criterion-referneced student achievement (i.e., status) as well as norm- and criterion-referenced student growth. These charts are those shown on the cover of the December 2009 Issue of Educational Measurement: Issues and Practice. See Betebenner (2009) and Betebenner (2012) for details.

Usage

growthAchievementPlot_Styles(
        gaPlot.sgp_object,
        gaPlot.students,
        gaPlot.percentile_trajectories,
        gaPlot.achievement_percentiles,
        gaPlot.show.scale.transformations,
        gaPlot.grade_range,
        gaPlot.max.order.for.progression,
        state,
        content_area,
        year,
        format,
        baseline,
        pdf.folder,
        assessment.name)

Arguments

gaPlot.sgp_object
The sgp_object containing system information for constructing the growth and achievement plot. Object is calculated using abcSGP or (at least) prepareSGP
gaPlot.students
Either NULL or a list of student IDs for whom one wishes to generate growth and achievement plots.
gaPlot.percentile_trajectories
A vector indicating the growth percentile trajectories to be depicted on the plot. If missing, the percentile trajectories will be the trajectories associated with the state supplied.
gaPlot.achievement_percentiles
A vector of percentiles that achievement (i.e., status) percentiles will be depicted across the range of grades.
gaPlot.show.scale.transformations
A boolean argument indicating whether to show the scale as a vertical axis if a scale transformation is applied to the supplied data.
gaPlot.grade_range
The grade range for which to demonstrate plot. If missing, function uses supplied state to derive grade range.
gaPlot.max.order.for.progression
The maximum coefficient matrix order to use for each progression. Default is utilizes the maximum order available with the coefficient matrices.
state
A two letter acronym for the state associated with the supplied data.
content_area
A character vector indicating the content area to produce the growth and achievement chart. Note that the supplied content area must match that used in the internal labelling of content area for the sgp_object.
year
The year for which to produce the growth and achievement plots.
format
Either "print" for light background or "presentation" for dark background slides.
baseline
Boolean variable indicating whether to create percentile trajectories using baseline referenced coefficient matrices.
pdf.folder
A character vector indicating where to put the produced growth and achievement plot.
assessment.name
A character vector indicating the assessment.name. If missing, the supplied state is used to determine the assessment.name.

Value

  • Function calls growthAchievementPlot and creates a growth and achievement chart and writes the result as a PDF to folder supplied by argument pdf.folder.

Details

Utility function used by visualizeSGP to call growthAchievementPlot.

References

Betebenner, D. W. (2012). Growth, standards, and accountability. In G. J. Cizek, Setting Performance Standards: Foundations, Methods & Innovations. 2nd Edition (pp. 439-450). New York: Routledge.

Betebenner, D. W. (2009). Norm- and criterion-referenced student growth. Educational Measurement: Issues and Practice, 28(4):42-51.