outputSGP(sgp_object,
state=NULL, output.type=c("LONG_Data", "LONG_FINAL_YEAR_Data", "WIDE_Data",
"INSTRUCTOR_Data"), baseline.sgps=FALSE, outputSGP_SUMMARY.years=NULL, outputSGP_SUMMARY.content_areas=NULL, outputSGP_INDIVIDUAL.years=NULL, outputSGP_INDIVIDUAL.content_areas=NULL, outputSGP.anonymize=FALSE, outputSGP.student.groups=NULL, outputSGP.directory="Data",
outputSGP.translate.names=TRUE,
outputSGP.projection.years.for.target=3,
outputSGP.pass.through.variables=NULL)sgp_object is missing.
LONG_Data, WIDE_Data, INSTRUCTOR_Data, SchoolView, RLI are supported
modes of output. LONG_Data exports the contents of the @Data slot in a pipe delimited format. LONG_FINAL_YEAR_Data exports the contents of the last year of the @Data slot in a pipe
delimited format. WIDE_Data exports a reshaped version of the @Data slot where each row is a unique student record. INSTRUCTOR_Data uses the
@Data_Supplementary$INSTRUCTOR_NUMBER table to export a long student by instructor number table. SchoolView exports tables used for representation in SchoolView. RLI exports
used for representation by RLI. The default exports LONG_Data, LONG_FINAL_YEAR_Data, WIDE_Data and INSTRUCTOR_Data.
Data.
abcSGP, prepareSGP, analyzeSGP, combineSGP, summarizeSGP## Not run:
# Demonstration_SGP <- prepareSGP(sgpData_LONG)
# Demonstration_SGP <- analyzeSGP(Demonstration_SGP)
# Demonstration_SGP <- combineSGP(Demonstration_SGP)
# outputSGP(Demonstration_SGP)
#
# ## Output current year
#
# outputSGP(Demonstration_SGP, output.type="LONG_FINAL_YEAR_Data")
# ## End(Not run)
Run the code above in your browser using DataLab