rliSGP(
sgp_object, additional.data=NULL,
state=NULL,
content_areas=c("MATHEMATICS", "READING", "EARLY_LITERACY"), testing.window, eow.or.update="UPDATE",
update.save.shell.only=FALSE, configuration.year,
sgp.percentiles.baseline=TRUE,
sgp.projections.baseline=TRUE,
sgp.projections.lagged.baseline=FALSE,
sgp.target.scale.scores=TRUE, update.ids=NULL,
SGPt=TRUE,
save.intermediate.results=FALSE,
coefficient.matrices=NULL,
goodness.of.fit.print=FALSE,
return.updated.shell=FALSE,
fix.duplicates="KEEP.ALL",
eow.calculate.sgps=FALSE, parallel.config=NULL)data.frame from which an SGP object can be produced. If data.frame is supplied, the current
window's data will be created from the last window present in the data.frame.
rliSGP should be run for ('MATHEMATICS', 'READING', and/or 'EARLY_LITERACY'). Default is all.
updateSGP to control whether baseline student growth percentiles are calculated. Default is TRUE.
updateSGP to control whether baseline student growth projections are calculated. Default is TRUE.
updateSGP to control whether lagged baseline student growth projections are calculated. Default is FALSE.
updateSGP to control whether scale score targets are calculated. Default is TRUE.
updateSGP indicating whether to save intermediate results from prepareSGP, analyzeSGP, and
combineSGP as part of the rliSGP analyses.
SGPstateData). Defaults to NULL (use those in SGPstateData).
updateSGP indicating whether to print goodness of fit plots associated with outcome. Default is FALSE.
sgp_object as part of call to rliSGP.
updateSGP further passed to analyzeSGP indicating whether student
growth percentiles are calculated as part of EOW analyses. Default is FALSE which results in just coefficient matrices being calculated.
## Not run:
# ####### For Within Window processing
#
# testSGP('RLI')
#
# ####### For End-of-Window processing
#
#
# ## End(Not run)
Run the code above in your browser using DataLab