studentGrowthProjections(panel.data, sgp.labels, grade.progression, content_area.progression=NULL,
year_lags.progression=NULL, grade.projection.sequence=NULL, content_area.projection.sequence=NULL, year_lags.projection.sequence=NULL, max.forward.progression.years=NULL, max.forward.progression.grade=NULL, max.order.for.progression, use.my.knots.boundaries, use.my.coefficient.matrices, panel.data.vnames, achievement.level.prior.vname=NULL, performance.level.cutscores, calculate.sgps=TRUE, convert.0and100=TRUE, trajectories.chunk.size=50000, sgp.projections.equated=NULL, projection.unit="YEAR", projection.unit.label=NULL, percentile.trajectory.values=NULL, return.percentile.trajectory.values=NULL, return.projection.group.identifier=NULL, return.projection.group.scale.scores=NULL, return.projection.group.dates=NULL, isotonize=TRUE, lag.increment=0,
sgp.exact.grade.progression=FALSE, projcuts.digits=NULL, SGPt=NULL, print.time.taken=TRUE)list containing longitudinal student data in wide format in panel.data$Panel_Data. See studentGrowthPercentiles
for data requirements. List object must also contain panel.data$Knots_Boundaries and panel.data$Coefficient_Matrices. See sgpData for an
exemplar data set. NOTE: The column position of the variables IS IMPORTANT, NOT the names of the variables.
sgp.labels, of the form list(my.year= ,
my.subject= ). The user-specified values are used to save the percentile growth projections/trajectories and identify coefficient matrices and knots & boundaries for calculation if
use.my.coefficient.matrices or
use.my.knots.boundaries is missing. Partly replaces previous argument proj.function.labels.
num.panels, max.num.scores, and num.prior.scores.
list(my.year= , my.subject= ) specifying the set of pre-calculated
knots and boundaries for B-spline calculations. Knot and boundaries are stored (and must be made available) with panel.data supplied as a
list in panel.data$Knots_Boundaries$my.year.my.subject. As of SGP_0.0-6.9 user can also supply a two letter state acronym to utilize knots and boundaries
within the SGPstateData data set supplied with the SGP package. If missing, function tries to retrieve knots and boundaries from
panel.data$Knots_Boundaries$my.year.my.subject where my.year and my.subject are provided by sgp.labels.
list(my.year= , my.subject= ) specifying the set of pre-calculated
coefficient matrices to use for percentile growth projection/trajectory calculations. Coefficient matrices are stores (and must be available) with panel.data
supplied as a list in panel.data$Coefficient_Matrices
$my.year.my.subject. If missing, function tries to retrieve coefficient matrices from
panel.data$Coefficient_Matrices$my.year.my.subject where my.year and my.subject are provided by sgp.labels.
performance.level.cutscores <- list(
Reading=list(GRADE_3=c(cut1, cut2, cut3),
GRADE_4=c(cut1, cut2, cut3),
. . .
GRADE_8=c(cut1, cut2, cut3)),
Math=list(GRADE_3=c(cut1, cut2, cut3),
. . .
GRADE_7=c(cut1, cut2, cut3),
GRADE_8=c(cut1, cut2, cut3)))
Note that the subject name must match that provided by sgp.labels. If cuts are not desired leave the cutscore unspecified, which is the default.
If your state's cutscores are not included in the SGPstateData data set or are incorrect, please contact
dbetebenner@nciea.org to have them added or corrected!
analyzeSGP when scale changes occur.
trajectory.chunk.size are passed to .get.percentile.trajectories and .get.trajectories.and.cuts.
"GRADE", the default, or
"YEAR".
projection.unit.
studentGrowthProjections analysis and time taken.
panel.data list object with the additional percentile growth trajectories/percentiles stored in
panel.data$SGProjections$my.year.my.subject consisting of student IDs and the associated percentile growth projections/trajectories and cuts.
The data frame contains projections/trajectories for each performance level cut-point supplied and each percentile cut the user specifies.
Betebenner, D. W. (2012). Growth, standards, and accountability. In G. J. Cizek, Setting Performance Standards: Foundations, Methods & Innovations. 2nd Edition (pp. 439-450). New York: Routledge.
Betebenner, D. W. (2009). Norm- and criterion-referenced student growth. Educational Measurement: Issues and Practice, 28(4):42-51.
Betebenner, D. W. (2008). Toward a normative understanding of student growth. In K. E. Ryan & L. A. Shepard (Eds.), The Future of Test Based Accountability (pp. 155-170). New York: Routledge.
Chernozhukov, V., Fernandez-Val, I. and Galichon, A. (2010), Quantile and Probability Curves Without Crossing. Econometrica, 78: 1093-1125.
studentGrowthPercentiles, sgpData## Not run:
# ## First calculate SGPs for 2014
# my.grade.sequences <- list(3:4, 3:5, 3:6, 3:7, 4:8)
# my.sgpData <- list(Panel_Data = sgpData)
#
# for (i in seq_along(my.grade.sequences)) {
# my.sgpData <- studentGrowthPercentiles(panel.data=my.sgpData,
# sgp.labels=list(my.year=2014, my.subject="Reading"),
# use.my.knots.boundaries="DEMO",
# grade.progression=my.grade.sequences[[i]])
# }
#
# ## Calculate Growth Projections
#
# my.grade.progressions <- list(3, 3:4, 3:5, 3:6, 4:7)
#
# for (i in seq_along(my.grade.progressions)) {
# my.sgpData <- studentGrowthProjections(panel.data=my.sgpData,
# sgp.labels=list(my.year=2014, my.subject="Reading"),
# projcuts.digits=0,
# projection.unit="GRADE",
# performance.level.cutscores="DEMO",
# percentile.trajectory.values=c(25, 50, 75),
# grade.progression=my.grade.progressions[[i]])
# }
#
# ## Save the Student Growth Projections Results to a .csv file:
#
# write.csv(my.sgpData$SGProjections$READING.2014,
# file= "2014_Reading_SGProjections.csv", row.names=FALSE, quote=FALSE)
# ## End(Not run)
Run the code above in your browser using DataLab